@echo OFF
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2011, 2012 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

REM Check if SCDEBUG flag is on

   if "%SCDEBUG%"=="1" (@echo on)

   SET BACKUP_DIR=C:\temp\sc_backup
   SET DIRHOME=
   SET JAVAPATH=
   SET VALIDVER="6.3.0"

   SET TPC_HOME=C:\\Program Files\\IBM\\TPC

   if NOT "%1"=="" (
       SET BACKUP_DIR=%1
   )

   if NOT EXIST "%TPC_HOME%\version.txt" (
     SET ERRORLEVEL=0
     GOTO FINALEOF
   )

   call :initializeJava

	SET LOG=%DIRHOME%\log\SCMigrateDB.log

   set DIRECDIR=%DIRHOME:\"=%
   set DIRECDIR=%DIRECDIR:\\=\%

   set TMPDIR=c:\temp\sc_backup
   SET BACKUPFILE=%TMPDIR%\sc_migrate_options.backup.bat
   SET RESTOREFILE=%TMPDIR%\sc_migrate_options.restore.bat

   if NOT EXIST %TMPDIR% (
       mkdir %TMPDIR%
   )
   
   REM We must stop the TPC server before the migration because the stop requires the current TPC credentials.
   start /WAIT cmd /C "%DIRHOME%\StorageControl\bin\stopStorageControl.bat" >> %LOG% 2>&1
   if ERRORLEVEL 1  GOTO STOPSTORAGECONTROL_FAILED
 
	REM  Must wait for the service to stop / start.  There is no sleep command on Windows.
	ping 127.0.0.1 -n 30 >> %LOG% 2>&1
   

   %JAVAPATH% -DBACKUPDIR=%BACKUP_DIR% -DBACKUPFILE=%BACKUPFILE% -DRESTOREFILE=%RESTOREFILE% -classpath %CLASSPATH% SCMigrateDB %DIRHOME% "%TPC_HOME%" 

   if ERRORLEVEL 1  GOTO migrateFailed

   if NOT EXIST %BACKUPFILE% GOTO migrateBackupNotfound
   if NOT EXIST %RESTOREFILE% GOTO migrateRestoreNotfound

   REM Use the system path for the old DatabaseAppHome location.
   db2cmd /w /i /c \%DIRECDIR%\StorageControl\bin\SCMigDBSupport.bat\" %BACKUPFILE%
   if ERRORLEVEL 1 GOTO migrateBackupFailed

   REM Check the database.properties file for the new DatabaseAppHome location.
   for /f "usebackq tokens=1,2 delims==" %%a in (`type %DIRHOME%\lwi\conf\overrides\database.properties`) do ( 
	if "%%a"=="rcs.DbmsDatabaseAppHome " ( 
		SET DB2HOME=%%b
	) 
   )
   
   REM Remove leading spaces from the DB2HOME variable.
   for /f "tokens=* delims= " %%a in ("%DB2HOME%") do set DB2HOME=%%a
   
   REM Run the DB2 Command from the new DB2 instance by supplying the full path.
   "%DB2HOME%"\bin\db2cmd /w /i /c \%DIRECDIR%\StorageControl\bin\SCMigDBSupport.bat\" %RESTOREFILE%
   if ERRORLEVEL 1 GOTO migrateRestoreFailed

   if ERRORLEVEL 0 (
   REM Remove the old TPCDB.  Use the system path for the old DatabaseAppHome location.
   echo "Removing the old TPCDB..." >> %LOG% 2>&1
   db2cmd /w /i /c "db2 drop database tpcdb" >> %LOG% 2>&1
   if ERRORLEVEL 1 GOTO migrateRestoreFailed
   )
   
   call %DIRHOME%\StorageControl\bin\SCChangeDBCfg.bat -u -p -v
   if ERRORLEVEL 1 GOTO changeDBFailed
   call :displayMessage "CHANGEDB_SUCCESS"



	REM Start the TPC server with the new credentials
   start /WAIT cmd /C "%DIRHOME%\StorageControl\bin\startStorageControl.bat" >> %LOG% 2>&1
   if ERRORLEVEL 1 GOTO STARTSTORAGECONTROL_FAILED

	REM  Must wait for the service to stop / start.  There is no sleep command on Windows.
	ping 127.0.0.1 -n 30 >> %LOG% 2>&1

   call :cleanupFiles

   GOTO FINALEOF 

:NOT_VALID_DIRECTOR 
   call :displayMessage "ISD_NOT_INSTALLED"
   GOTO FINALEOF 


:initializeJava
   REGEDIT /E DIR_REG.REG "HKEY_LOCAL_MACHINE\SOFTWARE\IBM\IBM Director Server\CurrentVersion" 

   set VALID_DIRECTOR=0

   if NOT EXIST DIR_REG.REG ( 
      goto MY_REG_NO_EXIST 
   ) 

   for /f "usebackq tokens=1,2 delims==" %%a in (`type DIR_REG.REG`) do ( 
    
     if %%a=="Version" ( 
        if %%b GEQ %VALIDVER% ( set VALID_DIRECTOR=1 ) else ( GOTO NOT_VALID_DIRECTOR )
     ) 
     if %%a=="Root" ( 
        SET DIRHOME=%%b
     ) 

   ) 

   SET CLASSPATH=%DIRHOME%\StorageControl\lib\*;%DIRHOME%\lwi\lib\passutils.jar;%DIRHOME%\lwi\lib\lwisecurity.jar
   SET JAVAPATH=%DIRHOME%\jre\bin\java
   GOTO FINALEOF

:displayMessage
   if %VALID_DIRECTOR% EQU 1 (
     %JAVAPATH% -classpath %CLASSPATH% DisplayMessage %1 %2 %3 >> %LOG%
   ) 
   GOTO FINALEOF

:STOPSTORAGECONTROL_FAILED
   call :displayMessage "STOPSTORAGECONTROL_FAILED"
   GOTO FINALEOF

:STARTSTORAGECONTROL_FAILED
   call :displayMessage "STARTSTORAGECONTROL_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:migrateFailed
   call :displayMessage "MIGRATION_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:migrateBackupNotfound
   call :displayMessage "MIGRATION_BACKUP_NOT_FOUND"
   call :cleanupFiles
   GOTO FINALEOF

:migrateBackupFailed
   call :displayMessage "MIGRATION_BACKUP_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:migrateRestoreNotfound
   call :displayMessage "MIGRATION_RESTORE_NOT_FOUND"
   call :cleanupFiles
   GOTO FINALEOF

:migrateRestoreFailed
   call :displayMessage "MIGRATION_RESTORE_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:changeDBFailed
   call :displayMessage "CHANGEDB_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:cleanupFiles
   REM Remove the backup and restore files if they exist
   del /F %BACKUPFILE% %RESTOREFILE% >> %LOG% 2>&1

:FINALEOF
