@echo OFF
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2011, 2012 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

   SET RETCODE=0
   SET BACKUP_DIR=C:\temp\sc_backup
   SET DIRHOME=
   SET JAVAPATH=
   SET TARGET_DIR=%BACKUP_DIR%
   SET VALIDVER="6.3.0"

   SET TPC_HOME=C:\Program Files\ibm\tpc

   call :initializeJava
   
   SET LOG=%DIRHOME%\log\SCSave.log

   set DIRECDIR=%DIRHOME:\"=%
   set DIRECDIR=%DIRECDIR:\\=\%

   set TMPDIR=c:\temp\sc_backup
   SET BACKUPFILE=%TMPDIR%\sc_migrate_options.backup.bat
   SET RESTOREFILE=%TMPDIR%\sc_migrate_options.restore.bat

   if NOT "%~1"=="" (
	echo "Setting BACKUP_DIR=%~1" >> %LOG% 2>&1
	SET BACKUP_DIR=%~1

	echo "Setting TARGET_DIR=%~1\sc_backup" >> %LOG% 2>&1
	SET TARGET_DIR=%~1\sc_backup
   )

	echo "BACKUP_DIR=%BACKUP_DIR%" >> %LOG% 2>&1
	echo "TARGET_DIR=%TARGET_DIR%" >> %LOG% 2>&1

   if NOT EXIST "%TARGET_DIR%" (
       mkdir "%TARGET_DIR%"
   )
  

   if NOT EXIST %TMPDIR% (
       mkdir %TMPDIR%
   )

   
   %JAVAPATH% -DBACKUPDIR="%BACKUP_DIR%" -DBACKUPFILE=%BACKUPFILE% -DRESTOREFILE=%RESTOREFILE% -classpath %CLASSPATH% SCMigrateDB %DIRHOME% "%TPC_HOME%" >> %LOG% 2>&1
   if ERRORLEVEL 1 (
      SET RETCODE=1
      call :displayMessage "MIGRATION_FAILED"
      GOTO EXITWITHSTATUS
   )

   if NOT EXIST %BACKUPFILE% (
      SET RETCODE=1
      call :displayMessage "MIGRATION_BACKUP_NOT_FOUND"
      GOTO EXITWITHSTATUS
   )

   REM Check the database.properties file for the current DB location.
   for /f "usebackq tokens=1,2 delims==" %%a in (`type %DIRHOME%\lwi\conf\overrides\database.properties`) do ( 
	if "%%a"=="rcs.DbmsDatabaseAppHome " ( 
		SET DB2HOME=%%b
	) 
   ) 

   REM Remove leading spaces from the DB2HOME variable.
   for /f "tokens=* delims= " %%a in ("%DB2HOME%") do set DB2HOME=%%a

   echo "Calling SCMigDBSupport.bat..." >> %LOG% 2>&1
   "%DB2HOME%"\bin\db2cmd /w /i /c \%DIRECDIR%\StorageControl\bin\SCMigDBSupport.bat\" %BACKUPFILE%
   if ERRORLEVEL 1 (
      SET RETCODE=1
      call :displayMessage "MIGRATION_BACKUP_FAILED"
      GOTO EXITWITHSTATUS
   )

   echo "Calling CopyFiles..." >> %LOG% 2>&1
   GOTO CopyFiles
:CopyFilesReturn

   echo "Calling EXITWITHSTATUS..." >> %LOG% 2>&1
   GOTO EXITWITHSTATUS

   GOTO FINALEOF 


:initializeJava
   REGEDIT /E DIR_REG.REG "HKEY_LOCAL_MACHINE\SOFTWARE\IBM\IBM Director Server\CurrentVersion" 

   set VALID_DIRECTOR=0

   if NOT EXIST DIR_REG.REG ( 
      SET RETCODE=1
      call :displayMessage "ISD_NOT_INSTALLED"
   ) 

   for /f "usebackq tokens=1,2 delims==" %%a in (`type DIR_REG.REG`) do ( 
    
     if %%a=="Version" ( 
        if %%b GEQ %VALIDVER% ( 
           set VALID_DIRECTOR=1 
        ) else ( 
              SET RETCODE=1
              call :displayMessage "ISD_NOT_INSTALLED"
        )
     ) 
     if %%a=="Root" ( 
        SET DIRHOME=%%b
     ) 

   ) 

   SET CLASSPATH=%DIRHOME%\StorageControl\lib\*;%DIRHOME%\lwi\lib\passutils.jar;%DIRHOME%\lwi\lib\lwisecurity.jar
   SET JAVAPATH=%DIRHOME%\jre\bin\java
   GOTO FINALEOF

:displayMessage
   if %VALID_DIRECTOR% EQU 1 (
     %JAVAPATH% -classpath %CLASSPATH% DisplayMessage %1 %2 %3 >> %LOG%
   ) 
   GOTO FINALEOF

:CopyFiles

    echo "Copying %DIRHOME%\lwi\conf\overrides\etpc.javaopt to %TARGET_DIR%" >> %LOG% 2>&1
    copy /y %DIRHOME%\lwi\conf\overrides\etpc.javaopt "%TARGET_DIR%" >> %LOG% 2>&1
    if ERRORLEVEL 1 (
       SET RETCODE=1
       echo "Error copying files." >> %LOG% 2>&1
       GOTO EXITWITHSTATUS
    )

    echo "Copying %DIRHOME%\proddata\advmgr\sc_advmgr.properties to %TARGET_DIR%" >> %LOG% 2>&1
    copy /y %DIRHOME%\proddata\advmgr\sc_advmgr.properties "%TARGET_DIR%" >> %LOG% 2>&1
    if ERRORLEVEL 1 (
       SET RETCODE=1
       echo "Error copying files." >> %LOG% 2>&1
       GOTO EXITWITHSTATUS
    )

    GOTO CopyFilesReturn

:cleanupFiles
   REM Remove the backup and restore files if they exist

   echo "Cleaning up files..." >> %LOG% 2>&1

   if EXIST "%BACKUPFILE%" (
      echo "Deleting %BACKUPFILE%" >> %LOG% 2>&1
      del /F %BACKUPFILE% >> %LOG% 2>&1
      if ERRORLEVEL 1 (
         SET RETCODE=1
         echo "Error deleting files." >> %LOG% 2>&1
      )
   )

   if EXIST "%RESTOREFILE%" (
      echo "Deleting %RESTOREFILE%" >> %LOG% 2>&1
      del /F %RESTOREFILE% >> %LOG% 2>&1
      if ERRORLEVEL 1 (
         SET RETCODE=1
         echo "Error deleting files." >> %LOG% 2>&1
      )
   )

   GOTO FINALEOF

:EXITWITHSTATUS

   echo "Calling cleanupFiles..." >> %LOG% 2>&1
   call :cleanupFiles

   echo "Exiting with RC=%RETCODE%" >> %LOG% 2>&1
   EXIT /B %RETCODE%
   GOTO FINALEOF

:FINALEOF
